==> hubzero-hubgraph_0.5.11.orig.tar.gz: hubzero-hubgraph-0.5.11/hubgraph-hubzero/source/lib/resources/users.js <==
module.exports = function(hg, done) {
	hg.event.observe('onTagsLoaded', function(client) {
		var getSql = function(id) {
			return 'SELECT ' +
				'params, CASE WHEN xp.public THEN registerDate ELSE NULL END AS date, \'members\' AS domain, xp.uidNumber AS id, ' +
				'CASE WHEN xp.public THEN xp.organization ELSE NULL END AS organization, xp.public, ' +
				'CASE WHEN xp.picture IS NOT NULL AND xp.picture != \'\' AND xp.public THEN CAST(concat(\'/site/members/\', CASE WHEN xp.uidNumber < 0 THEN \'n\' ELSE \'\' END, lpad(ABS(xp.uidNumber), 5, \'0\'), \'/\', xp.picture) AS CHAR) ELSE NULL END AS img_href, ' +
				'CASE WHEN xp.public THEN concat(\'/members/\', CASE WHEN xp.uidNumber < 0 THEN concat(\'n\', xp.uidNumber * -1) ELSE xp.uidNumber END) ELSE NULL END AS link, ' +
				'CASE WHEN xp.name = \'\' OR xp.name IS NULL THEN concat(coalesce(givenName, \'\'), coalesce(concat(\' \', middleName, \' \'), \' \'), coalesce(surname, \' \')) ELSE xp.name END AS title, ' + 
				'(SELECT CAST(group_concat(DISTINCT jto.tagid separator \'\\n\') AS CHAR) FROM jos_tags_object jto INNER JOIN jos_tags jt ON jt.id = jto.tagid WHERE jto.tbl = \'xprofiles\' AND jto.objectid = xp.uidNumber) AS tag_ids, ' +
				// formats entries in the author association table as JSON: {"sometable": count of contributions to that table}
				'(SELECT CAST(concat(\'{\', coalesce(group_concat(cont), \'\'), \'}\') AS CHAR) FROM (SELECT concat(\'"\', subtable, \'":\', count(distinct subid, subtable)) AS cont, authorid FROM jos_author_assoc GROUP BY authorid, subtable) i_should_feel_bad_about_this_sql_but_im_just_numb WHERE authorid = xp.uidNumber) AS contributions ' +
			'FROM jos_xprofiles xp ' +
			'LEFT JOIN jos_xprofiles_bio xpb ON xpb.uidNumber = xp.uidNumber ' + 
			(id ? ' WHERE xp.uidNumber = ' + (1*id) : '') 
		};
		console.log(getSql());
		
		var orgs = {};
		var add = function(res, idx) {
			if (!res.title || (!res.public && (!res.contributions || res.contributions == '{}'))) {
				return;
			}
			res.contributions = JSON.parse(res.contributions);
			res.access = {};
			hg.split(res.params).forEach(function(param) {
				var ma = param.match(/^access_([^=]+)=(.+)/);
				if (ma) {
					res.access[ma[1]] = ma[2].toLowerCase().replace(/\s+users$/, '');
				}
			});
			var any;
			if (any in res.contributions) {
				res.type = 'contributors';
			}
		//	maxCont = Math.max(maxCont, res.wiki_count + res.resource_count);

			res.organization = hg.stripslashes(res.organization);
			hg.addWithCommonConnections(res);
			if (!orgs[res.organization]) {
				hg.add({'title': res.organization, 'id': 'org:' + res.organization, 'domain': 'aliases'});
				orgs[res.organization] = true;
			}
			hg.add({'domain': 'aliases', 'id': 'user:' + res.id, 'title': res.title}); 
			hg.connect('alias', 'aliases', 'org:' + res.organization, 'members', res.id);
		};

		client.query(getSql(), function(err, results) {
			if (err) {
				throw err;
			}
			
			hg.add({'domain': 'domains', 'id': 'members'});
			hg.log(results.length + ' users');
			results.forEach(add);
			client.query('SELECT DISTINCT \'aliases\' AS domain, CAST(CONCAT(\'user:\', authorid) AS CHAR) AS id, name AS title FROM jos_author_assoc WHERE authorid NOT IN (SELECT id FROM jos_users)', function(err, results) {
				if (err) {
					throw err;	
				}
				console.log(results.length + ' virtual users');
				results.forEach(hg.addWithCommonConnections);
				done();
				hg.event.emit('onUsersLoaded', [client]);
			});
		});

		hg.event.observe('onUpdateXprofiles', function(client, row) {
			client.query(getSql(row.id), function(err, results) {
				if (err) {
					throw err;
				}
				if (results.length) {
					results.forEach(add);
				}
				else {
					hg.remove('members', row.id);
				}
			});
		});

		hg.event.observe('onInsertXprofiles', function(client, row) {
			client.query(getSql(row.id), function(err, results) {
				if (err) {
					throw err;
				}
				if (results.length) {
					results.forEach(add);
				}
				else {
					hg.remove('members', row.id);
				}
			});
		});

		hg.event.observe('onDeleteXprofiles', function(client, row) {
			hg.remove('members', row.id);
		});
	});
};

==> hubzero-hubgraph_0.5.11.5.orig.tar.gz: hubzero-hubgraph-0.5.11.5/hubgraph-hubzero/source/lib/resources/users.js <==
module.exports = function(hg, done) {
	hg.event.observe('onTagsLoaded', function(client) {
		var getSql = function(id) {
			return 'SELECT ' +
				'params, CASE WHEN xp.public THEN registerDate ELSE NULL END AS date, \'members\' AS domain, xp.uidNumber AS id, ' +
				'CASE WHEN xp.public THEN xp.organization ELSE NULL END AS organization, xp.public, ' +
				'CASE WHEN xp.picture IS NOT NULL AND xp.picture != \'\' AND xp.public THEN CAST(concat(\'/site/members/\', CASE WHEN xp.uidNumber < 0 THEN \'n\' ELSE \'\' END, lpad(ABS(xp.uidNumber), 5, \'0\'), \'/\', xp.picture) AS CHAR) ELSE NULL END AS img_href, ' +
				'CASE WHEN xp.public THEN concat(\'/members/\', CASE WHEN xp.uidNumber < 0 THEN concat(\'n\', xp.uidNumber * -1) ELSE xp.uidNumber END) ELSE NULL END AS link, ' +
				'CASE WHEN xp.name = \'\' OR xp.name IS NULL THEN concat(coalesce(givenName, \'\'), coalesce(concat(\' \', middleName, \' \'), \' \'), coalesce(surname, \' \')) ELSE xp.name END AS title, ' + 
				'(SELECT CAST(group_concat(DISTINCT jto.tagid separator \'\\n\') AS CHAR) FROM jos_tags_object jto INNER JOIN jos_tags jt ON jt.id = jto.tagid WHERE jto.tbl = \'xprofiles\' AND jto.objectid = xp.uidNumber) AS tag_ids, ' +
				// formats entries in the author association table as JSON: {"sometable": count of contributions to that table}
				'(SELECT CAST(concat(\'{\', coalesce(group_concat(cont), \'\'), \'}\') AS CHAR) FROM (SELECT concat(\'"\', subtable, \'":\', count(distinct subid, subtable)) AS cont, authorid, published FROM jos_author_assoc LEFT JOIN jos_resources ON subtable = \'resources\' AND jos_resources.id = subid GROUP BY authorid, subtable) al1 WHERE authorid = xp.uidNumber AND (published IS NULL OR published = 1)) AS contributions ' +
			'FROM jos_xprofiles xp ' +
			'LEFT JOIN jos_xprofiles_bio xpb ON xpb.uidNumber = xp.uidNumber ' + 
			(id ? ' WHERE xp.uidNumber = ' + (1*id) : '') 
		};
		console.log(getSql());
		
		var orgs = {};
		var add = function(res, idx) {
			if (!res.title || (!res.public && (!res.contributions || res.contributions == '{}'))) {
				return;
			}
			res.contributions = JSON.parse(res.contributions);
			res.access = {};
			res.params.split(',').forEach(function(param) {
				var ma = param.match(/access_([^:=]+)[:=](.+)/);
				if (ma) {
                                        res.access[ma[1].replace(/[^a-z]/g, '')] = ma[2].replace(/[^\d]/g, '')*1;
				}
			});
			if (res.access.tags !== undefined && res.access.tags !== 0) {
				res.tag_ids = '';
			}
			var any;
			if (any in res.contributions) {
				res.type = 'contributors';
			}
		//	maxCont = Math.max(maxCont, res.wiki_count + res.resource_count);

			res.organization = hg.stripslashes(res.organization);
			hg.addWithCommonConnections(res);
			if (!orgs[res.organization]) {
				hg.add({'title': res.organization, 'id': 'org:' + res.organization, 'domain': 'aliases'});
				orgs[res.organization] = true;
			}
			hg.add({'domain': 'aliases', 'id': 'user:' + res.id, 'title': res.title}); 
			hg.connect('alias', 'aliases', 'org:' + res.organization, 'members', res.id);
		};

		client.query(getSql(), function(err, results) {
			if (err) {
				throw err;
			}
			
			hg.add({'domain': 'domains', 'id': 'members'});
			hg.log(results.length + ' users');
			results.forEach(add);
			client.query('SELECT DISTINCT \'aliases\' AS domain, CAST(CONCAT(\'user:\', authorid) AS CHAR) AS id, name AS title FROM jos_author_assoc WHERE authorid NOT IN (SELECT id FROM jos_users)', function(err, results) {
				if (err) {
					throw err;	
				}
				console.log(results.length + ' virtual users');
				results.forEach(hg.addWithCommonConnections);
				done();
				hg.event.emit('onUsersLoaded', [client]);
			});
		});

		hg.event.observe('onUpdateXprofiles', function(client, row) {
			client.query(getSql(row.id), function(err, results) {
				if (err) {
					throw err;
				}
				if (results.length) {
					results.forEach(add);
				}
				else {
					hg.remove('members', row.id);
				}
			});
		});

		hg.event.observe('onInsertXprofiles', function(client, row) {
			client.query(getSql(row.id), function(err, results) {
				if (err) {
					throw err;
				}
				if (results.length) {
					results.forEach(add);
				}
				else {
					hg.remove('members', row.id);
				}
			});
		});

		hg.event.observe('onDeleteXprofiles', function(client, row) {
			hg.remove('members', row.id);
		});
	});
};
